um utils
=========

Project contains utility functions


Installation
------------

To install via `pip` run command

::

    $ pip install um


Contents
--------

Contents of the package

* utility functions
* visual package with color utilities
* collections module